@@ -25,6 +25,8 @@
 # 2017-06-22: J. Fox: eliminated extraneous code for defunct labels argument; small cleanup
 # 2017-12-07: J. Fox: added fill, fill.alpha subargs to ellipse arg, suggestion of Michael Friendly.
 # 2018-02-09: S. Weisberg removed the transform and family arguments from the default method
+# 2018-04-02: J. Fox: warning rather than error for too few colors.
+# 2018-04-12: J. Fox: clean up handling of groups arg.
 
 scatterplotMatrix <- function(x, ...){
   UseMethod("scatterplotMatrix")
@@ -81,9 +83,9 @@ scatterplotMatrix.default <-
            cex=par("cex"), cex.axis=par("cex.axis"),
            cex.labels=NULL, cex.main=par("cex.main"), row1attop=TRUE, ...){
   transform <- FALSE
-  family <- "bcPower"
+#  family <- "bcPower"
   force(col)
-  n.groups <- if(by.groups) length(levels(groups)) else 1
+#  n.groups <- if(by.groups) length(levels(groups)) else 1
   if(isFALSE(diagonal)) diagonal <- "none" else {
     diagonal.args <- applyDefaults(diagonal, defaults=list(method="adaptiveDensity"), type="diag")
     diagonal <- if(!isFALSE(diagonal.args)) diagonal.args$method
@@ -96,13 +98,19 @@ scatterplotMatrix.default <-
     reg.line <- regLine.args$method
     lty <- regLine.args$lty
     lwd <- regLine.args$lwd
-#    if(!by.groups) regLine.args$col <- col[1]
   } else reg.line <- "none"
   # setup smoother, now including spread
-  n.groups <- if(is.null(groups)) 1 else(length(levels(groups)))
+  n.groups <- if(is.null(groups)) 1
+    else {
+      if (!is.factor(groups)) groups <- as.factor(groups)
+      length(levels(groups))
+    }
   smoother.args <- applyDefaults(smooth, defaults=list(smoother=loessLine,
                               spread=(n.groups)==1, col=col, lty.smooth=2, lty.spread=4), type="smooth")
   if (!isFALSE(smoother.args)) {
+    # check for an argument 'var' in smoother.args.
+    if(!is.null(smoother.args$var)) smoother.args$spread <- smoother.args$var
+    # end change
     smoother <- smoother.args$smoother
     spread <- if(is.null(smoother.args$spread)) TRUE else smoother.args$spread
     smoother.args$spread <- smoother.args$smoother <- NULL
@@ -156,7 +164,7 @@ scatterplotMatrix.default <-
     x <- na.action(data.frame(groups, labels, x, stringsAsFactors=FALSE))
     #      groups <- as.factor(as.character(x[, 1]))
     groups <- x$groups
-    if (!is.factor(groups)) groups <- as.factor(as.character(x[,1]))
+#    if (!is.factor(groups)) groups <- as.factor(as.character(x[,1]))
     labels <- x[, 2]
     x <- x[, -(1:2)]
   }
@@ -284,22 +292,12 @@ scatterplotMatrix.default <-
     warning("the following groups are empty: ", paste(levels[counts == 0], collapse=", "))
     groups <- factor(groups, levels=levels[counts > 0])
   }
-  n.groups <- length(levels(groups))
-  if (n.groups > length(col)) stop("number of groups exceeds number of available col")
+#  n.groups <- length(levels(groups))
+  if (n.groups > length(col)) {
+    warning("number of groups exceeds number of available colors\n  colors are recycled")
+    col <- rep(col, n.groups)
+  }
   if (length(col) == 1) col <- rep(col, 3)
-
-#  if (transform != FALSE | length(transform) == ncol(x)){
-#    if (transform == TRUE & length(transform) == 1){
-#      transform <- if (n.groups > 1) coef(powerTransform(as.matrix(x) ~ groups, family=family), round=TRUE)
-#      else coef(powerTransform(x, family=family), round=TRUE)
-#    }
-#    for (i in 1:ncol(x)){
-#      x[, i] <- if (family == "bcPower")
-#        bcPower(x[, i], transform[i])
-#      else yjPower(x[, i], transform[i])
-#      var.labels[i] <- paste(var.labels[i], "^(", round(transform[i],2), ")", sep="")
-#    }
-#  }
   labs <- labels
   pairs(x, labels=var.labels,
         cex.axis=cex.axis, cex.main=cex.main, cex.labels=cex.labels, cex=cex,
